@@ -7,18 +7,18 @@ class ExceptionManager:
         try:
             self.api.repository.commit()
         except Exception as firstPreCommitException:
-            log.warning(handleLogErrorException, f'Failed to pre commit before persist {ReflectionHelper.getName(httpErrorLog)}. Going for a second attempt', exception=firstPreCommitException, muteStackTrace=True)
+            log.warning(self.handleErrorLog, f'Failed to pre commit before persist {ReflectionHelper.getName(httpErrorLog)}. Going for a second attempt', exception=firstPreCommitException, muteStackTrace=True)
             try:
                 self.api.repository.flush()
                 self.api.repository.commit()
             except Exception as secondPreCommitException:
-                log.warning(handleLogErrorException, f'Failed to pre commit before persist {ReflectionHelper.getName(httpErrorLog)}. Going for a third attempt', exception=secondPreCommitException, muteStackTrace=True)
+                log.warning(self.handleErrorLog, f'Failed to pre commit before persist {ReflectionHelper.getName(httpErrorLog)}. Going for a third attempt', exception=secondPreCommitException, muteStackTrace=True)
                 try:
                     self.api.repository.rollback()
                     self.api.repository.flush()
                     self.api.repository.commit()
                 except Exception as thirdPreCommitException:
-                    log.warning(handleLogErrorException, f'Failed to pre commit before persist {ReflectionHelper.getName(httpErrorLog)}', exception=thirdPreCommitException)
+                    log.warning(self.handleErrorLog, f'Failed to pre commit before persist {ReflectionHelper.getName(httpErrorLog)}', exception=thirdPreCommitException)
         httpErrorLog.reload()
         self.api.repository.saveAndCommit(httpErrorLog)
         # apiInstance.repository.reloadContextFromBackup()
